//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Sample/SampleModel.cpp
//! @brief     Implements class SampleModel
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Model/Sample/SampleModel.h"
#include "GUI/Model/Group/PropertyItem.h"
#include "GUI/Model/Sample/ItemWithMaterial.h"
#include "GUI/Model/Sample/MultiLayerItem.h"
#include "GUI/Model/Session/ModelPath.h"
#include <QApplication>
#include <QFontMetrics>
#include <QPixmap>

SampleModel::SampleModel(QObject* parent) : SessionModel(GUI::Session::XML::SampleModelTag, parent)
{
    setObjectName(GUI::Session::XML::SampleModelTag);
}

MultiLayerItem* SampleModel::multiLayerItem()
{
    return topItem<MultiLayerItem>();
}

QVector<MultiLayerItem*> SampleModel::multiLayerItems() const
{
    return topItems<MultiLayerItem>();
}

QVector<ItemWithMaterial*> SampleModel::itemsWithMaterial() const
{
    QVector<ItemWithMaterial*> result;

    for (auto* m : topItems<MultiLayerItem>())
        result << m->itemsWithMaterial();

    return result;
}

MultiLayerItem* SampleModel::addMultiLayer()
{
    return insertItem<MultiLayerItem>();
}

void SampleModel::removeMultiLayer(MultiLayerItem* item)
{
    removeItem(item);
}

QStringList SampleModel::multiLayerNames() const
{
    QStringList existingNames;
    for (const auto* item : multiLayerItems())
        existingNames << item->sampleName();
    return existingNames;
}
