//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Sample/SampleModel.h
//! @brief     Defines class SampleModel
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_SAMPLE_SAMPLEMODEL_H
#define BORNAGAIN_GUI_MODEL_SAMPLE_SAMPLEMODEL_H

#include "GUI/Model/Session/SessionModel.h"

class MultiLayerItem;
class ItemWithMaterial;

//! Main model to hold sample items.

class SampleModel : public SessionModel {
    Q_OBJECT

public:
    explicit SampleModel(QObject* parent = nullptr);

    MultiLayerItem* multiLayerItem();
    QVector<MultiLayerItem*> multiLayerItems() const;

    //! Returns vector of SessionItems having MaterialProperty on board.
    QVector<ItemWithMaterial*> itemsWithMaterial() const;

    //! Adds a multilayer and returns the new item.
    MultiLayerItem* addMultiLayer();
    void removeMultiLayer(MultiLayerItem* item);

    QStringList multiLayerNames() const;
};

#endif // BORNAGAIN_GUI_MODEL_SAMPLE_SAMPLEMODEL_H
