//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Session/ModelPath.h
//! @brief     Defines namespace GUI::Model::Path
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_SESSION_MODELPATH_H
#define BORNAGAIN_GUI_MODEL_SESSION_MODELPATH_H

#include <memory>
#include <vector>

class SessionItem;
class QModelIndex;
class SessionModel;
class QString;
class MaterialItem;

namespace GUI::Model::Path {

QString getPathFromIndex(const QModelIndex& index);

QString getPathFromItem(SessionItem* item);

QString getPathFromItem(const MaterialItem* item);

QModelIndex getIndexFromPath(const SessionModel* model, const QString& path);

bool isValidItem(SessionModel* model, SessionItem* item, const QModelIndex& parent);

//! Returns ancestor of given modelType for given item.
//!
//! For example, returns corresponding jobItem owning ParameterItem via ParameterContainer.
SessionItem* ancestor(SessionItem* item, const QString& requiredModelType);

} // namespace GUI::Model::Path

#endif // BORNAGAIN_GUI_MODEL_SESSION_MODELPATH_H
