//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/HardParticle/FormFactorCone.h
//! @brief     Defines class FormFactorCone
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_SAMPLE_HARDPARTICLE_FORMFACTORCONE_H
#define BORNAGAIN_SAMPLE_HARDPARTICLE_FORMFACTORCONE_H

#include "Sample/Particle/IBornFF.h"

//! A conical frustum (cone truncated parallel to the base) with circular base.
//! @ingroup hardParticle

class FormFactorCone : public IBornFF {
public:
    std::string className() const final { return "FormFactorCone"; }

    FormFactorCone(std::vector<double> P);
    FormFactorCone(double radius, double height, double alpha);

    FormFactorCone* clone() const override
    {
        return new FormFactorCone(m_radius, m_height, m_alpha);
    }

    double height() const { return m_height; }
    double alpha() const { return m_alpha; }
    double radius() const { return m_radius; }

    double radialExtension() const override { return m_radius; }

    complex_t formfactor(C3 q) const override;

private:
    const double& m_radius;
    const double& m_height;
    const double& m_alpha;
    double m_cot_alpha;
};

#endif // BORNAGAIN_SAMPLE_HARDPARTICLE_FORMFACTORCONE_H
